@@ -17,7 +17,7 @@ class ApiError(Exception):
     """AdvantageAir Error"""
 
     def __init__(self,message):
-        super().__init__(self.message)
+        super().__init__(message)
 
 
 class advantage_air:
@@ -45,10 +45,13 @@ class advantage_air:
                     data = await resp.json(content_type=None)
                     if "aircons" in data:
                         return data
+            except AssertionError:
+                error = "Response status not 200."
+                pass
             except ClientError as err:
                 error = err
                 pass
-            except asyncio.TimeoutError as err:
+            except asyncio.TimeoutError:
                 error = "Connection timed out."
                 pass
             except SyntaxError as err:
@@ -56,7 +59,7 @@ class advantage_air:
                 break
 
             await asyncio.sleep(1)
-        raise ApiError(f"No valid response after {count} failed attempt{['','s'][count>1]}. Last error was {error}")
+        raise ApiError(f"No valid response after {count} failed attempt{['','s'][count>1]}. Last error was: {error}")
 
     async def async_change(self, change):
         """Merge changes with queue and send when possible, returning True when done"""
